@@ -39,7 +39,7 @@ class Translator:
     beacon_re = re.compile(r"(?P<chr>[^-]+)\s*:\s*(?P<pos>\d+)\s*(?P<ref>\w+)\s*>\s*(?P<alt>\w+)")
     gnomad_re = re.compile(r"(?P<chr>[^-]+)-(?P<pos>\d+)-(?P<ref>\w+)-(?P<alt>\w+)")
     hgvs_re = re.compile(r"[^:]+:[cgnpr]\.")
-    spdi_re = re.compile(r"(?P<ac>[^:]+):(?P<pos>\d+):(?P<del_len_or_seq>\w+):(?P<ins_seq>\w+)")
+    spdi_re = re.compile(r"(?P<ac>[^:]+):(?P<pos>\d+):(?P<del_len_or_seq>\w*):(?P<ins_seq>\w*)")
 
 
     def __init__(self,
@@ -93,17 +93,16 @@ class Translator:
         """
         if allele.state.type == "SequenceState":
             allele.state = models.LiteralSequenceExpression(
-                type="LiteralSequenceExpression",
                 sequence=allele.state.sequence,
             )
         if allele.location.interval.type == "SimpleInterval":
             allele.location.interval = models.SequenceInterval(
-                type="SequenceInterval",
-                start=models.Number(value=allele.location.interval.start, type="Number"),
-                end=models.Number(value=allele.location.interval.end, type="Number"),
+                start=models.Number(value=allele.location.interval.start),
+                end=models.Number(value=allele.location.interval.end),
             )
         return allele
 
+
     ############################################################################
     ## INTERNAL
 
@@ -141,7 +140,8 @@ class Translator:
 
         interval = models.SequenceInterval(start=models.Number(value=start),
                                            end=models.Number(value=end))
-        location = models.Location(sequence_id=sequence_id, interval=interval)
+        location = models.SequenceLocation(sequence_id=sequence_id,
+                                           interval=interval)
         state = models.LiteralSequenceExpression(sequence=ins_seq)
         allele = models.Allele(location=location, state=state)
         allele = self._post_process_imported_allele(allele)
@@ -182,7 +182,7 @@ class Translator:
 
         interval = models.SequenceInterval(start=models.Number(value=start),
                                            end=models.Number(value=end))
-        location = models.Location(sequence_id=sequence_id, interval=interval)
+        location = models.SequenceLocation(sequence_id=sequence_id, interval=interval)
         sstate = models.LiteralSequenceExpression(sequence=ins_seq)
         allele = models.Allele(location=location, state=sstate)
         allele = self._post_process_imported_allele(allele)
@@ -251,7 +251,7 @@ class Translator:
         else:
             raise ValueError(f"HGVS variant type {sv.posedit.edit.type} is unsupported")
 
-        location = models.Location(sequence_id=sequence_id, interval=interval)
+        location = models.SequenceLocation(sequence_id=sequence_id, interval=interval)
         sstate = models.LiteralSequenceExpression(sequence=state)
         allele = models.Allele(location=location, state=sstate)
         allele = self._post_process_imported_allele(allele)
@@ -296,7 +296,7 @@ class Translator:
 
         interval = models.SequenceInterval(start=models.Number(value=start),
                                            end=models.Number(value=end))
-        location = models.Location(sequence_id=sequence_id, interval=interval)
+        location = models.SequenceLocation(sequence_id=sequence_id, interval=interval)
         sstate = models.LiteralSequenceExpression(sequence=ins_seq)
         allele = models.Allele(location=location, state=sstate)
         allele = self._post_process_imported_allele(allele)
@@ -352,8 +352,8 @@ class Translator:
                 return "g"
             return None
 
-        if self.is_valid_allele(vo):
-            raise ValueError(f"_to_hgvs requires a VRS Allele with SequenceLocation and LiteralSequenceExpression")
+        if not self.is_valid_allele(vo):
+            raise ValueError("_to_hgvs requires a VRS Allele with SequenceLocation and LiteralSequenceExpression")
 
         sequence_id = str(vo.location.sequence_id)
         aliases = self.data_proxy.translate_sequence_identifier(sequence_id, namespace)
@@ -420,6 +420,7 @@ class Translator:
 
         return list(set(hgvs_exprs))
 
+
     def _to_spdi(self, vo, namespace="refseq"):
         """generates a *list* of SPDI expressions for VRS Allele.
 
@@ -438,23 +439,23 @@ class Translator:
         is expected to be normalized per VRS spec.
 
         """
-
-        if self.is_valid_allele(vo):
-            raise ValueError(f"_to_spdi requires a VRS Allele with SequenceLocation and LiteralSequenceExpression")
+        if not self.is_valid_allele(vo):
+            raise ValueError("_to_spdi requires a VRS Allele with SequenceLocation and LiteralSequenceExpression")
 
         sequence_id = str(vo.location.sequence_id)
         aliases = self.data_proxy.translate_sequence_identifier(sequence_id, namespace)
         aliases = [a.split(":")[1] for a in aliases]
-
         start, end = vo.location.interval.start.value, vo.location.interval.end.value
         spdi_tail = f":{start}:{end-start}:{vo.state.sequence}"
         spdis = [a + spdi_tail for a in aliases]
         return spdis
 
+
     def is_valid_allele(self, vo):
-        return (type(vo).__name__ != "Allele"
-                or type(vo.location).__name__ != "SequenceLocation"
-                or type(vo.state).__name__ != "LiteralSequenceExpression")
+        return (vo.type == "Allele"
+                and vo.location.type == "SequenceLocation"
+                and vo.state.type == "LiteralSequenceExpression")
+
 
     @lazy_property
     def _hgvs_parser(self):
